@@ -15,16 +15,23 @@ def cli():
     """
     import docopt
     args = docopt.docopt(cli.__doc__)
+    files = args["<file>"]
+    xpath = args['<xpath>']
+    endl = '\0' if args["-0"] else '\n'
     import sys
     import html5lib
     from lxml import etree
-    for f in args["<file>"]:
+    for f in files:
         if f == '-':
             f = sys.stdin.buffer
         else:
-            f = open(f,'rb')
+            f = open(f, 'rb')
+
         tree = html5lib.parse(f, "lxml", namespaceHTMLElements=False)
-        for item in tree.xpath(args['<xpath>']):
-            if not isinstance(item,str):
+
+        items = tree.xpath(xpath)
+
+        for item in items:
+            if not isinstance(item, str):
                 item = html5lib.serialize(item)
-            print(item)
+            print(item, end=endl)
